@@ -14,21 +14,21 @@
 #   See the License for the specific language governing permissions and
 #   limitations under the License.
 
+import os
 import unittest
 import hpsdnclient as hp
 
-SDNCTL = '10.44.254.129'
-USER = 'sdn'
-PASS = 'skyline'
-
+SDNCTL = os.getenv("SDNCTL")
+USER = os.getenv("SDNUSER")
+PASS = os.getenv("SDNPASS")
 
 class ApiTestCase(unittest.TestCase):
     @classmethod
     def setUpClass(cls):
         auth = hp.XAuthToken(server=SDNCTL, user=USER, password=PASS)
-        cls._api = hp.Api(controller=SDNCTL, auth=auth)
+        cls.api = hp.Api(controller=SDNCTL, auth=auth)
 
     @classmethod
     def tearDownClass(cls):
-        cls._api = None
+        cls.api = None
 
